pyswarms.discrete package
=========================

.. automodule:: pyswarms.discrete

pyswarms.discrete.binary module
--------------------------------

.. automodule:: pyswarms.discrete.binary
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__